@@ -1,26 +1,13 @@
-from typing import Optional, TYPE_CHECKING, Tuple, Type
+from typing import TYPE_CHECKING, Tuple, Type
 from weakref import proxy
 
-import ormar
 from ormar.fields import BaseField
 from ormar.fields.many_to_many import ManyToManyField
-from ormar.relations import Relation
 
 if TYPE_CHECKING:  # pragma no cover
     from ormar import Model
 
 
-def register_missing_relation(
-    parent: "Model", child: "Model", child_name: str
-) -> Optional[Relation]:
-    ormar.models.expand_reverse_relationships(child.__class__)
-    name = parent.resolve_relation_name(parent, child)
-    field = parent.Meta.model_fields[name]
-    parent._orm._add_relation(field)
-    parent_relation = parent._orm._get(child_name)
-    return parent_relation
-
-
 def get_relations_sides_and_names(
     to_field: Type[BaseField],
     parent: "Model",
